@@ -29,4 +29,4 @@ class SDK:
         return self._sdk.refund()
 
     def ok(self):
-        return self._sdk.ok()
+        return self._sdk is not None and self._sdk.ok()
