@@ -5,20 +5,63 @@ from iso8601 import parse_date
 import pytz
 from ..MuviBase import MuviBase
 
-
+map_errors = {
+    1:"pedir autorizacion",
+    2: "pedir autorizacion",
+    3: "comercio invalido",
+    4: "capturar tarjeta",
+    5: "denegada",
+    7: "retenga y llame",
+    8: "ingreso manual incorrecto",
+    12: "transac. invalida",
+    13: "monto invalido",
+    14: "tarjeta invalida",
+    19: "auto approve in receivepayment",
+    25: "no existe original",
+    28: "servicio no disponible",
+    30: "error en formato",
+    31: "the parameter must be specified.",
+    38: "excede ing.de pin",
+    39: "ingreso manual incorrecto",
+    43: "retener tarjeta",
+    45: "no opera en cuotas",
+    46: "tarjeta no vigente",
+    47: "pin requerido",
+    48: "excede max. cuotas",
+    49: "error fecha vencim.",
+    50: "entrega supera limite",
+    51: "fondos insuficientes",
+    53: "cuenta inexistente",
+    54: "tarjeta vencida",
+    55: "pin incorrecto",
+    56: "tarj. no habilitada",
+    57: "trans. no permitida",
+    58: "servicio invalido",
+    61: "excede limite",
+    65: "excede lim. tarjeta",
+    76: "llamar al emisor",
+    77: "error plan/cuotas",
+    89: "terminal invalida",
+    91: "emisor fuera linea",
+    94: "nro. sec. duplicad",
+    95: "re-transmitiendo",
+    96: "error en sistema",
+    97: "error en sistema host",
+    98: "ver rechazo en ticket",
+}
 arg_tz = pytz.timezone('America/Buenos_Aires')
 
-def _format_card(response):
+def frmat_card(response):
     if 'card' in response:
         return {
             'id': response['card']['id'],
             'card_type': 'not_found',
-            'last_four_digits': response['card']['last_four_digits'],
+           'last_four_digits': response['card']['last_four_digits'],
             'cardholder': {
                 'name': response['card']['cardholder']['name']
             },
             'expiration_month': response['card']['expiration_month'],
-            'expiration_year': response['card']['expiration_year'],
+        'expiration_year': response['card']['expiration_year'],
         }
         
     if 'card_data' in response and 'tokens' not in response['card_data']:
@@ -50,7 +93,11 @@ def _format(response):
         response['status'] = 'approved'
         response['status_detail'] = 'accredited'
     elif response['status'] == 'rejected':
-        response['status_detail'] = 'rejected'
+        id_error = int(response['status_details']['error']['reason']['id'])
+        if id_error in map_errors:
+            response['status_detail'] = map_errors[response[id_error]]
+        else:
+            response['status_detail'] = 'ERROR DESCONOCIDO'
 
     date = parse_date(response['date']).astimezone(arg_tz)
     result = {
@@ -101,12 +148,10 @@ class Payment(MuviBase):
             'establishment_name': self.merchant_name,
             'sub_payments': [],
             'amount':total_amount, # En cualquier tipo de payment
+            'installments':installments,
         }
 
-        if 'application_fee' not in payment_data:   # El pago va 100% al hijo
-            body['site_id'] = self.site_id
-            body['installments'] = installments
-        else:
+        if 'application_fee' in payment_data:
             application_fee = round(payment_data['application_fee'], 2) * 100
             body['payment_type'] = 'distributed'
             body['sub_payments'] = [
