@@ -47,4 +47,4 @@ class Card(MuviBase):
         if mp_response['status'] > 299:
             return self.error(message='Customer not found', status=mp_response['status'])
         cards = mp_response['response']
-        return self.ok([_format(card) for card in cards], status=mp_response['status'])
+        return self.ok({'results': [_format(card) for card in cards]}, status=mp_response['status'])
