@@ -1,7 +1,7 @@
 import mercadopago
 from iso8601 import parse_date
-from datetime import datetime
-from ..response import ok, error
+
+from ..MuviBase import MuviBase
 
 
 def _format_card(response):
@@ -25,13 +25,13 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'processor': 'mercadopago',
-        'payment_day':datetime.now()
+        'payment_day': parse_date(response['date_created'])     # es igual a date_created
     }
 
 
-class Payment:
-    def __init__(self, sdk: mercadopago.SDK):
+class Payment(MuviBase):
+    def __init__(self, processor: str, sdk: mercadopago.SDK):
+        super().__init__(processor)
         self.sdk = sdk
 
     def create(self, payment_data: dict):
@@ -58,8 +58,8 @@ class Payment:
 
         if 'payer' in payment_data:
             payment_data_mp["payer"] = {
-                "first_name": payment_data['payer']["first_name"],
-                "last_name": payment_data['payer']["last_name"],
+                "first_name": payment_data['payer']["nombre"],
+                "last_name": payment_data['payer']["apellido"],
                 "address": None
             }
             if 'mercadopago_id' in payment_data['payer']:
@@ -69,14 +69,13 @@ class Payment:
 
         payment_response = self.sdk.payment().create(payment_data_mp)
         if payment_response['status'] < 400:
-            return ok(_format(payment_response['response']))
+            return self.ok(_format(payment_response['response']), status=payment_response['status'])
 
-        payment_response['response']['processor'] = 'mercadopago'
-        return error(payment_response['response'])
+        return self.error(payment_response['response'], status=payment_response['status'])
 
     def get(self, payment_id: int):
         payment_response = self.sdk.payment().get(payment_id)
         if payment_response['status'] < 400:
-            return ok(payment_response['response'])
+            return self.ok(payment_response['response'], status=payment_response['status'])
 
-        return error(payment_response['response'])
+        return self.error(payment_response['response'], status=payment_response['status'])
